@@ -1,25 +1,25 @@
 from __future__ import division
 
+import functools
 import platform
 import warnings
-from functools import partial
 
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-import rasterio
+import rasterio as rio
+import transonic
 from rasterio import plot
 from scipy import ndimage, spatial, stats
-from transonic import boost, set_backend_for_this_module
 
-if platform.system() == "Windows":
-    backend = "numba"
+if platform.system() == 'Windows':
+    backend = 'numba'
 else:
-    backend = "pythran"
+    backend = 'pythran'
 
-set_backend_for_this_module(backend)
+transonic.set_backend_for_this_module(backend)
 
-__all__ = ["Landscape"]
+__all__ = ['Landscape']
 
 # sometimes pixel resolutions in GeoTIFF files are floats therefore
 # compparisons (e.g., `cell_width == cell_height`) should allow for some
@@ -28,8 +28,8 @@ CELLLENGTH_RTOL = 0.001
 KERNEL_MOORE = ndimage.generate_binary_structure(2, 2)
 
 
-@boost
-def compute_adjacency_arr(padded_arr: "uint32[:,:]", num_classes: "int"):
+@transonic.boost
+def compute_adjacency_arr(padded_arr: 'uint32[:,:]', num_classes: 'int'):
     # flat-array approach to pixel adjacency from link below:
     # https://ilovesymposia.com/2016/12/20/numba-in-the-real-world/
     # the first axis of `adjacency_arr` is of fixed size of 2 and serves to
@@ -79,29 +79,30 @@ class Landscape:
     """Class representing a raster landscape upon which the landscape metrics
     will be computed
     """
+
     def __init__(self, landscape, res=None, nodata=None, transform=None,
                  **kwargs):
         """
         Parameters
         ----------
-        landscape : np.ndarray or str, file object or pathlib.Path object
+        landscape : numpy.ndarray or str, file object or pathlib.Path object
             A landscape array with pixel values corresponding to a set of land
             use/land cover classes, or a filename or URL, a file object opened
-            in binary ('rb') mode, or a Path object. If not a `np.ndarray`,
+            in binary ('rb') mode, or a Path object. If not a `numpy.ndarray`,
             `landscape` will be passed to `rasterio.open`
         res : tuple, optional
             The (x, y) resolution of the dataset. Required if `landscape` is a
-            `np.ndarray`
+            `numpy.ndarray`
         nodata : int, optional
             Value to be assigned to pixels with no data. It will be set to 0
-            if `landscape` is a `np.ndarray`
+            if `landscape` is a `numpy.ndarray`
         transform : affine.Affine, optional
             Transformation from pixel coordinates to coordinate reference
             system. If `landscape` is a path to a GeoTiff, this argument will
             be ignored and extracted from the raster's metadata instead
         **kwargs : optional
             Keyword arguments to be passed to `rasterio.open`. Ignored if
-            `landscape` is an `np.ndarray`
+            `landscape` is an `numpy.ndarray`
         """
         if isinstance(landscape, np.ndarray):
             landscape_arr = np.copy(landscape)
@@ -111,7 +112,7 @@ class Landscape:
             if nodata is None:
                 nodata = 0
         else:
-            with rasterio.open(landscape, nodata=nodata, **kwargs) as src:
+            with rio.open(landscape, nodata=nodata, **kwargs) as src:
                 landscape_arr = src.read(1)
                 if res is None:
                     res = src.res
@@ -140,39 +141,41 @@ class Landscape:
     # constants
 
     PATCH_METRICS = [
-        "area",
-        "perimeter",
-        "perimeter_area_ratio",
-        "shape_index",
-        "fractal_dimension",
-        "euclidean_nearest_neighbor",
+        'area',
+        'perimeter',
+        'perimeter_area_ratio',
+        'shape_index',
+        'fractal_dimension',
+        'euclidean_nearest_neighbor',
     ]  # 'contiguity_index', 'proximity'
 
     DISTR_METRICS = [
-        patch_metric + "_" + suffix for patch_metric in PATCH_METRICS
-        for suffix in ["mn", "am", "md", "ra", "sd", "cv"]
+        patch_metric + '_' + suffix for patch_metric in PATCH_METRICS
+        for suffix in ['mn', 'am', 'md', 'ra', 'sd', 'cv']
     ]
 
     CLASS_METRICS = [
-        "total_area",
-        "proportion_of_landscape",
-        "number_of_patches",
-        "patch_density",
-        "largest_patch_index",
-        "total_edge",
-        "edge_density",
-        "landscape_shape_index",
+        'total_area',
+        'proportion_of_landscape',
+        'number_of_patches',
+        'patch_density',
+        'largest_patch_index',
+        'total_edge',
+        'edge_density',
+        'landscape_shape_index',
+        'effective_mesh_size',
     ] + DISTR_METRICS
 
     LANDSCAPE_METRICS = ([
-        "total_area",
-        "number_of_patches",
-        "patch_density",
-        "largest_patch_index",
-        "total_edge",
-        "edge_density",
-        "landscape_shape_index",
-    ] + DISTR_METRICS + ["contagion", "shannon_diversity_index"])
+        'total_area',
+        'number_of_patches',
+        'patch_density',
+        'largest_patch_index',
+        'total_edge',
+        'edge_density',
+        'landscape_shape_index',
+        'effective_mesh_size',
+    ] + DISTR_METRICS + ['contagion', 'shannon_diversity_index'])
 
     # compute methods
 
@@ -215,7 +218,7 @@ class Landscape:
             patch_arr = np.pad(
                 label_arr[patch_slice] == i,
                 pad_width=1,
-                mode="constant",
+                mode='constant',
                 constant_values=False,
             )  # self.nodata
 
@@ -398,7 +401,7 @@ class Landscape:
                     np.full(self._num_patches_dict[class_val], class_val)
                     for class_val in self.classes
                 ]),
-                name="class_val",
+                name='class_val',
             )
 
             return self._cached_patch_class_ser
@@ -413,7 +416,7 @@ class Landscape:
                     self.compute_patch_areas(self.class_label(class_val)[0])
                     for class_val in self.classes
                 ]),
-                name="area",
+                name='area',
             )
 
             return self._cached_patch_area_ser
@@ -429,7 +432,7 @@ class Landscape:
                         self.class_label(class_val)[0])
                     for class_val in self.classes
                 ]),
-                name="perimeter",
+                name='perimeter',
             )
 
             return self._cached_patch_perimeter_ser
@@ -445,7 +448,7 @@ class Landscape:
                         self.class_label(class_val)[0])
                     for class_val in self.classes
                 ]),
-                name="euclidean_nearest_neighbor",
+                name='euclidean_nearest_neighbor',
             )
 
             return self._cached_patch_euclidean_nearest_neighbor_ser
@@ -472,7 +475,7 @@ class Landscape:
             padded_arr = np.pad(
                 reclassified_arr,
                 pad_width=1,
-                mode="constant",
+                mode='constant',
                 constant_values=num_classes,
             ).astype(np.uint32)
 
@@ -484,13 +487,13 @@ class Landscape:
             adjacency_cols = np.concatenate([self.classes, [self.nodata]])
             adjacency_df = pd.DataFrame(
                 index=pd.MultiIndex.from_product(
-                    [["horizontal", "vertical"], adjacency_cols],
-                    names=["direction", "class_val"],
+                    [['horizontal', 'vertical'], adjacency_cols],
+                    names=['direction', 'class_val'],
                 ),
                 columns=adjacency_cols,
             )
-            adjacency_df.loc["horizontal"] = adjacency_arr[0]
-            adjacency_df.loc["vertical"] = adjacency_arr[1]
+            adjacency_df.loc['horizontal'] = adjacency_arr[0]
+            adjacency_df.loc['vertical'] = adjacency_arr[1]
 
             # cache it
             self._cached_adjacency_df = adjacency_df
@@ -541,11 +544,11 @@ class Landscape:
     # metric distribution statistics
 
     def _metric_reduce(
-        self,
-        class_val,
-        patch_metric_method,
-        patch_metric_method_kws,
-        reduce_method,
+            self,
+            class_val,
+            patch_metric_method,
+            patch_metric_method_kws,
+            reduce_method,
     ):
         if patch_metric_method_kws is None:
             patch_metrics = patch_metric_method(class_val)
@@ -556,7 +559,7 @@ class Landscape:
             # ACHTUNG: dropping columns from a `pd.DataFrame` until leaving it
             # with only one column will still return a `pd.DataFrame`, so we
             # must convert to `pd.Series` manually (e.g., with `iloc`)
-            patch_metrics = patch_metrics.drop("class_val", axis=1).iloc[:, 0]
+            patch_metrics = patch_metrics.drop('class_val', axis=1).iloc[:, 0]
 
         return reduce_method(patch_metrics)
 
@@ -571,13 +574,13 @@ class Landscape:
         area = self.area(class_val)
 
         if class_val is None:
-            area = area["area"]
+            area = area['area']
 
         return self._metric_reduce(
             class_val,
             patch_metric_method,
             patch_metric_method_kws,
-            partial(np.average, weights=area),
+            functools.partial(np.average, weights=area),
         )
 
     def _metric_md(self, class_val, patch_metric_method,
@@ -600,11 +603,11 @@ class Landscape:
                                    patch_metric_method_kws, np.std)
 
     def _metric_cv(
-        self,
-        class_val,
-        patch_metric_method,
-        patch_metric_method_kws=None,
-        percent=True,
+            self,
+            class_val,
+            patch_metric_method,
+            patch_metric_method_kws=None,
+            percent=True,
     ):
         metric_cv = self._metric_reduce(
             class_val,
@@ -627,7 +630,7 @@ class Landscape:
         The area of each patch of the landscape
 
         .. math::
-           AREA = a_{i,j} \\quad [hec] \; or \; [m]
+           AREA = a_{i,j} \\quad [hec] \\; or \\; [m]
 
         Parameters
         ----------
@@ -641,7 +644,8 @@ class Landscape:
 
         Returns
         -------
-        AREA : pd.Series if `class_val` is provided, pd.DataFrame otherwise
+        AREA : pandas.Series if `class_val` is provided, pandas.DataFrame
+            otherwise
             AREA > 0, without limit
         """
 
@@ -659,8 +663,8 @@ class Landscape:
 
         if class_val is None:
             return pd.DataFrame({
-                "class_val": self._patch_class_ser,
-                "area": area_ser
+                'class_val': self._patch_class_ser,
+                'area': area_ser
             })
         else:
             return area_ser
@@ -681,7 +685,8 @@ class Landscape:
 
         Returns
         -------
-        PERIM : pd.Series if `class_val` is provided, pd.DataFrame otherwise
+        PERIM : pandas.Series if `class_val` is provided, pandas.DataFrame
+            otherwise
             PERIM > 0, without limit
         """
 
@@ -691,8 +696,8 @@ class Landscape:
 
         if class_val is None:
             return pd.DataFrame({
-                "class_val": self._patch_class_ser,
-                "perimeter": perimeter_ser
+                'class_val': self._patch_class_ser,
+                'perimeter': perimeter_ser
             })
         else:
             return perimeter_ser
@@ -707,7 +712,7 @@ class Landscape:
         smaller perimeter-area ratio.
 
         .. math::
-           PARA = \\frac{p_{i,j}}{a_{i,j}} \\quad [m/hec] \; or \; [m/m^2]
+           PARA = \\frac{p_{i,j}}{a_{i,j}} \\quad [m/hec] \\; or \\; [m/m^2]
 
         Parameters
         ----------
@@ -721,7 +726,8 @@ class Landscape:
 
         Returns
         -------
-        PARA : pd.Series if `class_val` is provided, pd.DataFrame otherwise
+        PARA : pandas.Series if `class_val` is provided, pandas.DataFrame
+            otherwise
             PARA > 0, without limit
         """
 
@@ -742,15 +748,15 @@ class Landscape:
 
         if class_val is None:
             return pd.DataFrame({
-                "class_val":
+                'class_val':
                 self._patch_class_ser,
-                "perimeter_area_ratio":
+                'perimeter_area_ratio':
                 perimeter_area_ratio_ser,
             })
         else:
             # ensure that the returned `pd.Series` has a name (so `seaborn`
             # plots can automatically label the axes)
-            perimeter_area_ratio_ser.name = "perimeter_area_ratio"
+            perimeter_area_ratio_ser.name = 'perimeter_area_ratio'
             return perimeter_area_ratio_ser
 
     def shape_index(self, class_val=None):
@@ -760,7 +766,7 @@ class Landscape:
         shape.
 
         .. math::
-           SHAPE = \\frac{.25 \; p_{i,j}}{\\sqrt{a_{i,j}}}
+           SHAPE = \\frac{.25 \\; p_{i,j}}{\\sqrt{a_{i,j}}}
 
         Parameters
         ----------
@@ -771,10 +777,11 @@ class Landscape:
 
         Returns
         -------
-        SHAPE : pd.Series if `class_val` is provided, pd.DataFrame otherwise
+        SHAPE : pandas.Series if `class_val` is provided, pandas.DataFrame
+            otherwise
             SHAPE >= 1, without limit ; SHAPE equals 1 when the patch
             is maximally compact, and increases without limit as patch shape
-            becomes more regular
+            becomes more irregular
         """
 
         area_ser = self._get_patch_area_ser(class_val)
@@ -784,13 +791,13 @@ class Landscape:
 
         if class_val is None:
             return pd.DataFrame({
-                "class_val": self._patch_class_ser,
-                "shape_index": shape_index_ser,
+                'class_val': self._patch_class_ser,
+                'shape_index': shape_index_ser,
             })
         else:
             # ensure that the returned `pd.Series` has a name (so `seaborn`
             # plots can automatically label the axes)
-            shape_index_ser.name = "shape_index"
+            shape_index_ser.name = 'shape_index'
             return shape_index_ser
 
     def fractal_dimension(self, class_val=None):
@@ -799,7 +806,7 @@ class Landscape:
         sizes
 
         .. math::
-           FRAC = \\frac{2 \; ln (.25 \; p_{i,j})}{ln (a_{i,j})}
+           FRAC = \\frac{2 \\; ln (.25 \\; p_{i,j})}{ln (a_{i,j})}
 
         Parameters
         ----------
@@ -810,7 +817,8 @@ class Landscape:
 
         Returns
         -------
-        FRAC : pd.Series if `class_val` is provided, pd.DataFrame otherwise
+        FRAC : pandas.Series if `class_val` is provided, pandas.DataFrame
+            otherwise
             1 <= FRAC <=2 ; for a two-dimensional patch, FRAC approaches 1 for
             very simple shapes such as squares, and approaches 2 for complex
             plane-filling shapes
@@ -825,13 +833,13 @@ class Landscape:
 
         if class_val is None:
             return pd.DataFrame({
-                "class_val": self._patch_area_ser,
-                "fractal_dimension": fractal_dimension_ser,
+                'class_val': self._patch_area_ser,
+                'fractal_dimension': fractal_dimension_ser,
             })
         else:
             # ensure that the returned `pd.Series` has a name (so `seaborn`
             # plots can automatically label the axes)
-            fractal_dimension_ser.name = "fractal_dimension"
+            fractal_dimension_ser.name = 'fractal_dimension'
             return fractal_dimension_ser
 
     def continguity_index(self, class_val=None):
@@ -877,8 +885,8 @@ class Landscape:
             nearest neighbors decreases
         """
 
-        euclidean_nearest_neighbor_ser = self._get_patch_euclidean_nearest_neighbor_ser(
-            class_val)
+        euclidean_nearest_neighbor_ser = \
+            self._get_patch_euclidean_nearest_neighbor_ser(class_val)
 
         if class_val is None:
             for class_val in self.classes:
@@ -892,9 +900,9 @@ class Landscape:
                     )
 
             return pd.DataFrame({
-                "class_val":
+                'class_val':
                 self._patch_class_ser,
-                "euclidean_nearest_neighbor":
+                'euclidean_nearest_neighbor':
                 euclidean_nearest_neighbor_ser,
             })
         else:
@@ -942,13 +950,13 @@ class Landscape:
         class level as in:
 
         .. math::
-           TA_i = \\sum_{j=1}^{n_i} a_{i,j} \\quad [hec] \; or \; [m] \\quad
-           (class \; i)
+           TA_i = \\sum_{j=1}^{n_i} a_{i,j} \\quad [hec] \\; or \\; [m] \\quad
+           (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
         .. math::
-           TA = A \\quad [hec] \; or \; [m] \\quad (landscape)
+           TA = A \\quad [hec] \\; or \\; [m] \\quad (landscape)
 
         Parameters
         ----------
@@ -1014,7 +1022,7 @@ class Landscape:
         at the class level as in:
 
         .. math::
-           NP_i = n_i \\quad (class \; i)
+           NP_i = n_i \\quad (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
@@ -1048,13 +1056,14 @@ class Landscape:
         the class level as in:
 
         .. math::
-           PD_i = \\frac{n_i}{A} \\quad [1/hec] \; or \; [1/m^2] \\quad (class
-           \; i)
+           PD_i = \\frac{n_i}{A} \\quad [1/hec] \\; or \\; [1/m^2] \\quad
+           (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
         .. math::
-           PD = \\frac{N}{A} \\quad [1/hec] \; or \; [1/m^2] \\quad (landscape)
+           PD = \\frac{N}{A} \\quad [1/hec] \\; or \\; [1/m^2] \\quad
+           (landscape)
 
         Parameters
         ----------
@@ -1098,7 +1107,7 @@ class Landscape:
         in:
 
         .. math::
-           LPI_i = \\frac{1}{A} \\max_{j=1}^{n_i} a_{i,j} \\quad (class \; i)
+           LPI_i = \\frac{1}{A} \\max_{j=1}^{n_i} a_{i,j} \\quad (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
@@ -1139,7 +1148,7 @@ class Landscape:
         metric is computed at the class level as in:
 
         .. math::
-           TE_i = \\sum_{k=1}^{m} e_{i,k} \\quad [m] \\quad (class \; i)
+           TE_i = \\sum_{k=1}^{m} e_{i,k} \\quad [m] \\quad (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
@@ -1169,7 +1178,7 @@ class Landscape:
                     np.pad(
                         self.landscape_arr,
                         pad_width=1,
-                        mode="constant",
+                        mode='constant',
                         constant_values=self.nodata,
                     ))
             else:
@@ -1184,8 +1193,8 @@ class Landscape:
                 else:
                     total_edge = 0
                     for direction, length in [
-                        ("horizontal", self.cell_width),
-                        ("vertical", self.cell_height),
+                        ('horizontal', self.cell_width),
+                        ('vertical', self.cell_height),
                     ]:
                         adjacency_arr = np.triu(
                             self._adjacency_df.loc[direction].drop(
@@ -1212,8 +1221,8 @@ class Landscape:
                 else:
                     total_edge = 0
                     for direction, length in [
-                        ("horizontal", self.cell_width),
-                        ("vertical", self.cell_height),
+                        ('horizontal', self.cell_width),
+                        ('vertical', self.cell_height),
                     ]:
                         total_edge += (
                             np.sum(self._adjacency_df.loc[direction].drop(
@@ -1229,13 +1238,14 @@ class Landscape:
         metric is computed at the class level as in:
 
         .. math::
-           ED_i = \\frac{1}{A} \\sum_{k=1}^{m} e_{i,k} \\quad [m/hec] \; or
-           \; [m/m^2] \\quad (class \; i)
+           ED_i = \\frac{1}{A} \\sum_{k=1}^{m} e_{i,k} \\quad [m/hec] \\; or
+           \\; [m/m^2] \\quad (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
         .. math::
-           ED = \\frac{E}{A} \\quad [m/hec] \; or \; [m/m^2] \\quad (landscape)
+           ED = \\frac{E}{A} \\quad [m/hec] \\; or \\; [m/m^2] \\quad
+           (landscape)
 
         Parameters
         ----------
@@ -1287,7 +1297,7 @@ class Landscape:
         area_mn : float
         """
 
-        return self._metric_mn(class_val, self.area, {"hectares": hectares})
+        return self._metric_mn(class_val, self.area, {'hectares': hectares})
 
     def area_am(self, class_val=None, hectares=True):
         """
@@ -1309,7 +1319,7 @@ class Landscape:
         area_am : float
         """
 
-        return self._metric_am(class_val, self.area, {"hectares": hectares})
+        return self._metric_am(class_val, self.area, {'hectares': hectares})
 
     def area_md(self, class_val=None, hectares=True):
         """
@@ -1331,7 +1341,7 @@ class Landscape:
         area_md : float
         """
 
-        return self._metric_md(class_val, self.area, {"hectares": hectares})
+        return self._metric_md(class_val, self.area, {'hectares': hectares})
 
     def area_ra(self, class_val=None, hectares=True):
         """
@@ -1353,7 +1363,7 @@ class Landscape:
         area_ra : float
         """
 
-        return self._metric_ra(class_val, self.area, {"hectares": hectares})
+        return self._metric_ra(class_val, self.area, {'hectares': hectares})
 
     def area_sd(self, class_val=None, hectares=True):
         """
@@ -1375,7 +1385,7 @@ class Landscape:
         area_sd : float
         """
 
-        return self._metric_sd(class_val, self.area, {"hectares": hectares})
+        return self._metric_sd(class_val, self.area, {'hectares': hectares})
 
     def area_cv(self, class_val=None, percent=True):
         """
@@ -1539,7 +1549,7 @@ class Landscape:
         """
 
         return self._metric_mn(class_val, self.perimeter_area_ratio,
-                               {"hectares": hectares})
+                               {'hectares': hectares})
 
     def perimeter_area_ratio_am(self, class_val=None, hectares=True):
         """
@@ -1562,7 +1572,7 @@ class Landscape:
         """
 
         return self._metric_am(class_val, self.perimeter_area_ratio,
-                               {"hectares": hectares})
+                               {'hectares': hectares})
 
     def perimeter_area_ratio_md(self, class_val=None, hectares=True):
         """
@@ -1585,7 +1595,7 @@ class Landscape:
         """
 
         return self._metric_md(class_val, self.perimeter_area_ratio,
-                               {"hectares": hectares})
+                               {'hectares': hectares})
 
     def perimeter_area_ratio_ra(self, class_val=None, hectares=True):
         """
@@ -1608,7 +1618,7 @@ class Landscape:
         """
 
         return self._metric_ra(class_val, self.perimeter_area_ratio,
-                               {"hectares": hectares})
+                               {'hectares': hectares})
 
     def perimeter_area_ratio_sd(self, class_val=None, hectares=True):
         """
@@ -1631,7 +1641,7 @@ class Landscape:
         """
 
         return self._metric_sd(class_val, self.perimeter_area_ratio,
-                               {"hectares": hectares})
+                               {'hectares': hectares})
 
     def perimeter_area_ratio_cv(self, class_val=None, percent=True):
         """
@@ -2205,7 +2215,7 @@ class Landscape:
 
         Returns
         -------
-        enn_sd :
+        enn_sd : float
         """
 
         return self._metric_sd(class_val, self.euclidean_nearest_neighbor)
@@ -2242,7 +2252,7 @@ class Landscape:
 
         .. math::
            LSI_i = \\frac{.25 \\sum \\limits_{k=1}^{m} e_{i,k}}{\\sqrt{A}}
-           \\quad (class \; i)
+           \\quad (class \\; i)
 
         otherwise, the metric is computed at the landscape level as in:
 
@@ -2314,6 +2324,47 @@ class Landscape:
         # TODO
         raise NotImplementedError
 
+    def effective_mesh_size(self, class_val=None, hectares=True):
+        """
+        Measure of aggregation based on the cumulative patch size distribution.
+        If `class_val` is provided, the metric is computed at the class level
+        as in:
+
+        .. math::
+           MESH_i = \\frac{1}{A} \\sum_{j=1}^{n_i} a_{i,j}^2 \\quad [m] \\quad
+           (class \\; i)
+
+        otherwise, the metric is computed at the landscape level as in:
+
+        .. math::
+           MESH = \\frac{1}{A} \\sum_{i=1}^{m} \\sum_{j=1}^{n_i} a_{i,j}^2
+           \\quad [m] \\quad (landscape)
+
+        Parameters
+        ----------
+        class_val : int, optional
+            If provided, the metric will be computed at the level of the
+            corresponding class, otherwise it will be computed at the
+            landscape level
+        hectares : bool, default True
+            Whether the landscape area should be converted to hectares (tends
+            to yield more legible values for the metric)
+
+        Returns
+        -------
+        mesh : float
+            cell_area / A <= MESH <= A ; MESH approaches its minimum when
+            there is a single corresponding patch of one pixel, and approaches
+            its maximum when the landscape consists of a single patch
+        """
+        mesh = np.sum(self._get_patch_area_ser(class_val)**2) / \
+            self.landscape_area
+
+        if hectares:
+            mesh /= 10000
+
+        return mesh
+
     ###########################################################################
     # landscape-level metrics
 
@@ -2390,7 +2441,7 @@ class Landscape:
         computed at the landscape level as in:
 
         .. math::
-           SHDI = - \\sum \\limits_{i=1}^{m} \\Big( P_i \; ln P_i \\Big)
+           SHDI = - \\sum \\limits_{i=1}^{m} \\Big( P_i \\; ln P_i \\Big)
 
         Returns
         -------
@@ -2439,7 +2490,7 @@ class Landscape:
 
         Returns
         -------
-        df : pd.DataFrame
+        df : pandas.DataFrame
             Dataframe with the values computed for each patch (index) and
             metric (columns)
         """
@@ -2467,7 +2518,7 @@ class Landscape:
 
                 metrics_dfs.append(
                     getattr(self,
-                            metric)(**metric_kws).drop("class_val", axis=1))
+                            metric)(**metric_kws).drop('class_val', axis=1))
 
         except AttributeError:
             raise ValueError("{metric} is not among {Landscape.PATCH_METRICS}")
@@ -2477,7 +2528,7 @@ class Landscape:
                     metric=metric))
 
         df = pd.concat(metrics_dfs, axis=1)  # [['class_val'] + patch_metrics]
-        df.index.name = "patch_id"
+        df.index.name = 'patch_id'
 
         return df
 
@@ -2505,7 +2556,7 @@ class Landscape:
 
         Returns
         -------
-        df : pd.DataFrame
+        df : pandas.DataFrame
             Dataframe with the values computed for each class (index) and
             metric (columns)
         """
@@ -2559,7 +2610,7 @@ class Landscape:
                     metric=metric))
 
         df = pd.concat(metrics_sers, axis=1)
-        df.index.name = "class_val"
+        df.index.name = 'class_val'
 
         return df
 
@@ -2583,7 +2634,7 @@ class Landscape:
 
         Returns
         -------
-        df : pd.DataFrame
+        df : pandas.DataFrame
             Dataframe with the values computed at the landscape level (one row
             only) for each metric (columns)
         """
@@ -2635,8 +2686,8 @@ class Landscape:
 
         Returns
         -------
-        ax : matplotlib axis
-            axis with plot data
+        ax : matplotlib.axes.Axes
+            Returns the `Axes` object with the plot drawn onto it
         """
 
         if cmap is None:
@@ -2647,10 +2698,12 @@ class Landscape:
 
         if ax is None:
             fig, ax = plt.subplots(figsize=figsize)
-            ax.set_aspect("equal")
+            ax.set_aspect('equal')
 
-        ax = plot.show(self.landscape_arr, ax=ax, transform=self.transform,
-                       cmap=cmap, **show_kws)
+        ax = plot.show(
+            np.where(self.landscape_arr != self.nodata, self.landscape_arr,
+                     self.nodata), ax=ax, transform=self.transform, cmap=cmap,
+            **show_kws)
 
         if legend:
             im = ax.get_images()[0]
@@ -2658,7 +2711,7 @@ class Landscape:
                 ax.plot(
                     ax.get_xlim()[0],
                     ax.get_ylim()[0],
-                    "o",
+                    'o',
                     c=cmap(im.norm(class_val)),
                     label=class_val,
                 )
